"""
Logging handler.
"""
import logging

# Set up logging to ``/dev/null`` like a library is supposed to.
# http://docs.python.org/3.3/howto/logging.html#configuring-logging-for-a-library
class NullHandler(logging.Handler):
    """
    Set up logging to `/dev/null`.
    """
    def emit(self, record):
        pass

logging.getLogger('gcp_token_federation').addHandler(NullHandler())
